@@ -1,6 +1,6 @@
-__version__ = "1.1.1"
+__version__ = "1.2.0"
 
-from discordn import bot, command, embed, member, client, messageable, snowflake, voiceclient, errors
+from . import bot, command, embed, member, client, messageable, snowflake, tasks, voiceclient, errors
 
 
 def patch():
@@ -11,5 +11,6 @@ def patch():
     client.patch()
     messageable.patch()
     snowflake.patch()
+    tasks.patch()
     voiceclient.patch()
     errors.patch()
